@@ -153,12 +153,12 @@ class OcrdResourceManager():
         if usage == 'without-extension':
             return Path(name).stem
 
-    def _download_impl(self, url, filename, progress_cb=None):
+    def _download_impl(self, url, filename, progress_cb=None, size=None):
         log = getLogger('ocrd.resource_manager._download_impl')
         log.info("Downloading %s to %s" % (url, filename))
         with open(filename, 'wb') as f:
             with requests.get(url, stream=True) as r:
-                total = int(r.headers.get('content-length'))
+                total = size if size else int(r.headers.get('content-length'))
                 for data in r.iter_content(chunk_size=4096):
                     if progress_cb:
                         progress_cb(len(data))
@@ -189,6 +189,7 @@ class OcrdResourceManager():
         resource_type='file',
         path_in_archive='.',
         progress_cb=None,
+        size=None,
     ):
         """
         Download a resource by URL
@@ -212,7 +213,7 @@ class OcrdResourceManager():
         elif resource_type == 'tarball':
             with pushd_popd(tempdir=True):
                 if is_url:
-                    self._download_impl(url, 'download.tar.xx', progress_cb)
+                    self._download_impl(url, 'download.tar.xx', progress_cb, size)
                 else:
                     self._copy_impl(url, 'download.tar.xx', progress_cb)
                 Path('out').mkdir()
